@@ -1,4 +1,4 @@
-# Copyrights 2007-2013 by [Mark Overmeer].
+# Copyrights 2007-2014 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.01.
@@ -7,36 +7,34 @@ use strict;
 
 package Log::Report::Die;
 use vars '$VERSION';
-$VERSION = '0.998';
+$VERSION = '1.05';
 
 use base 'Exporter';
 
 our @EXPORT = qw/die_decode/;
 
-use Log::Report 'log-report';
 use POSIX  qw/locale_h/;
 
 
 sub die_decode($)
 {   my @text   = split /\n/, $_[0];
     @text or return ();
-
-    $text[0]   =~ s/\.$//;   # inconsequently used
     chomp $text[-1];
 
     my %opt    = (errno => $! + 0);
     my $err    = "$!";
 
     my $dietxt = $text[0];
-    if($text[0] =~ s/ at (.+) line (\d+)$// )
+    if($text[0] =~ s/ at (.+) line (\d+)\.?$// )
     {   $opt{location} = [undef, $1, $2, undef];
     }
     elsif(@text > 1 && $text[1] =~ m/^\s*at (.+) line (\d+)\.?$/ )
-    {   $opt{location} = [undef, $1, $2, undef];
+    {   # sometimes people carp/confess with \n, folding the line
+        $opt{location} = [undef, $1, $2, undef];
         splice @text, 1, 1;
     }
 
-    $text[0] =~ s/\s*[.:;]?\s*$err\s*$//
+    $text[0] =~ s/\s*[.:;]?\s*$err\s*$//  # the $err is translation sensitive
         or delete $opt{errno};
 
     my $msg = shift @text;
