@@ -1,4 +1,4 @@
-# Copyrights 2007-2013 by [Mark Overmeer].
+# Copyrights 2007-2014 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.01.
@@ -7,7 +7,7 @@ use strict;
 
 package Log::Report::Dispatcher::Try;
 use vars '$VERSION';
-$VERSION = '0.998';
+$VERSION = '1.05';
 
 use base 'Log::Report::Dispatcher';
 
@@ -16,15 +16,17 @@ use Log::Report::Exception;
 
 
 use overload
-    bool => 'failed'
-  , '""' => 'showStatus';
+    bool     => 'failed'
+  , '""'     => 'showStatus'
+  , fallback => 1;
 
+#-----------------
 
 sub init($)
 {   my ($self, $args) = @_;
     defined $self->SUPER::init($args) or return;
     $self->{exceptions} = delete $args->{exceptions} || [];
-    $self->{died} = delete $args->{died};
+    $self->{died}       = delete $args->{died};
     $self;
 }
 
@@ -35,6 +37,7 @@ sub close()
     $self;
 }
 
+#-----------------
 
 sub died(;$)
 {   my $self = shift;
@@ -44,21 +47,25 @@ sub died(;$)
 
 sub exceptions() { @{shift->{exceptions}} }
 
+#-----------------
 
-sub log($$$)
-{   my ($self, $opts, $reason, $message) = @_;
+sub log($$$$)
+{   my ($self, $opts, $reason, $message, $domain) = @_;
 
     # If "try" does not want a stack, because of its mode,
     # then don't produce one later!  (too late)
     $opts->{stack}    ||= [];
     $opts->{location} ||= '';
 
-    push @{$self->{exceptions}}
-      , Log::Report::Exception->new
-          ( reason      => $reason
-          , report_opts => $opts
-          , message     => $message
-          );
+    my $e = Log::Report::Exception->new
+     ( reason      => $reason
+     , report_opts => $opts
+     , message     => $message
+     );
+
+    my $is_fatal = exists $opts->{is_fatal} ? $opts->{is_fatal} : $e->isFatal;
+
+    push @{$self->{exceptions}}, $e;
 
     # later changed into nice message
     $self->{died} ||= $opts->{is_fatal};
@@ -66,14 +73,11 @@ sub log($$$)
 }
 
 
-sub reportAll(@) { $_->throw(@_) for shift->exceptions }
-
-
-sub reportFatal(@) { $_->throw(@_) for shift->wasFatal }
+sub reportFatal(@) { $_->throw(@_) for shift->wasFatal   }
+sub reportAll(@)   { $_->throw(@_) for shift->exceptions }
 
 #-----------------
 
-
 sub failed()  {   shift->{died}}
 sub success() { ! shift->{died}}
 
